@@ -3,7 +3,8 @@ from .containers import ContainerConfig, HostConfig, LogConfig, Ulimit
 from .healthcheck import Healthcheck
 from .networks import EndpointConfig, IPAMConfig, IPAMPool, NetworkingConfig
 from .services import (
-    ContainerSpec, DriverConfig, EndpointSpec, Mount, Resources, RestartPolicy,
-    SecretReference, ServiceMode, TaskTemplate, UpdateConfig
+    ConfigReference, ContainerSpec, DNSConfig, DriverConfig, EndpointSpec,
+    Mount, Placement, Privileges, Resources, RestartPolicy, SecretReference,
+    ServiceMode, TaskTemplate, UpdateConfig
 )
 from .swarm import SwarmSpec, SwarmExternalCA
